/// Copyright Thomas Nagy 2007
/// License: QPL

#include <QtGlobal>

#ifndef conh
#define conh

#define ff4 10.
#define nof(x, y) ((int) ((y) * ((int) ((x) / (y)))))
#define ff2(x)  (nof(x, ff4/2.))
#define ff1(x)   (nof(x, ff4))

#define mu(x)   #x

#define fu(x, y)  mu(x##y)

#define ff3 15




#define mix(x, y) <%x^=y;y^=x;x^=y;%>

 #define CONST const

#ifdef Q_OS_DARWIN
#define szam 300
#define nbr 500
#define rctsiz 9999999
#define arany 10.0
#define R_ 120.0
#define D_ 4.0
#define rws 300
#define lng "long"
#define lrg "larg"
#define xxxp "posx"
#define yyyp "posy"
#define dir  "ori"
#endif

#define moc(x) fu(x, moc)

#define gratype(x) (QGraphicsItem::UserType + x)

#incl\
ude \
"aux.h"

#include <QHash>
#include <QVariant>

#define zagv QHash<int, QVariant>

qreal adelk(qreal a, qreal b);
qreal irnyjl(qreal a, qreal b);

/* TODO: values hardcoded in some places */

#define ossz 0
#define krszt 1
#define gyok "/"
#define oszy 2
#define lnc 3
#define nlnc 4
#define cmze "tmp"
#define vlsztt 5
#define mod 6
#define kivdlk 7
#define krsztszn 8
#define krszelgyk 9
#define nytt 10
#define vadrtc 11
#define kivdlk2 12
#define kivdlk3 13

#define nreg nytt





#define jelzpo 4

#define jelzpt 6 

#define nztutb 1
#define nztegns 2
#define nztsvg 3
#define nztosz 4
#define nztoz2 5
#define aljlk 6

#define ures "Empty"

#define aegy do <% while(1)<%%> %> while (0)

#define errmsg "im sorry dave, im afraid i cant do that"

/* end - con.h */
#endif

